Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(169)

Unified Diff: ui/views/animation/ink_drop_state.h

Issue 1832963002: MD - add ripples to DL shelf items (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix another TODO Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/animation/ink_drop_animation_unittest.cc ('k') | ui/views/animation/ink_drop_state.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/animation/ink_drop_state.h
diff --git a/ui/views/animation/ink_drop_state.h b/ui/views/animation/ink_drop_state.h
index 16f4fc2bee6f1aa584a29ed294b2605f5bfafba6..2456455c5da0b62d60e62bbd8f73d07b4b947d3a 100644
--- a/ui/views/animation/ink_drop_state.h
+++ b/ui/views/animation/ink_drop_state.h
@@ -16,21 +16,21 @@ enum class InkDropState {
// The ink drop is not visible.
HIDDEN,
// The view is being interacted with but the action to be triggered has not
- // yet been determined.
+ // yet been determined, e.g. a mouse button down.
ACTION_PENDING,
- // The quick action for the view has been triggered. e.g. a tap gesture to
- // click a button.
- QUICK_ACTION,
- // A view is being interacted with and the pending action will be a 'slow'
- // action. e.g. a long press that is still active before releasing.
- SLOW_ACTION_PENDING,
- // The slow action for the view has been triggered. e.g. a long press release
- // to bring up a menu.
- SLOW_ACTION,
+ // The quick action for the view has been triggered, e.g. a tap gesture or a
+ // mouse click on a button.
+ ACTION_TRIGGERED,
+ // A view is being interacted with and the pending action will be a secondary
+ // action, e.g. a long press.
+ ALTERNATE_ACTION_PENDING,
+ // The alternate action for the view has been triggered, e.g. a long press
+ // release to bring up a menu.
+ ALTERNATE_ACTION_TRIGGERED,
// An active state for a view that is not currently being interacted with.
// e.g. a pressed button that is showing a menu.
ACTIVATED,
- // A previously active state has been toggled to inactive. e.g. a drop down
+ // A previously active state has been toggled to inactive, e.g. a drop down
// menu is closed.
DEACTIVATED,
};
« no previous file with comments | « ui/views/animation/ink_drop_animation_unittest.cc ('k') | ui/views/animation/ink_drop_state.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698